@@ -18,10 +18,6 @@ static const char *colors[][3]      = {
 	[SchemeSel]  = { col_gray4, col_cyan,  col_cyan  },
 };
 
-static const char *const autostart[] = {
-	NULL /* terminate */
-};
-
 /* tagging */
 static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };
 
@@ -32,13 +28,12 @@ static const Rule rules[] = {
 	 */
 	/* class      instance    title       tags mask     isfloating   monitor */
 	{ "xfce4-terminal", NULL,       NULL,       0,            0,       -1 },
-        { "Firefox",        NULL,       NULL,       1 << 1,       0,       -1 },
-        { "Pidgin",         NULL,       NULL,       1 << 2,       1,        1 },
-        { "Skype",          NULL,       NULL,       1 << 2,       1,        1 },
-        { "Vlc",            NULL,       NULL,       1 << 5,       0,       -1 },
-        { "Emacs",          NULL,       NULL,       1 << 3,       0,       -1 },
-        { "Evince",         NULL,       NULL,       1 << 4,       0,       -1 },
-        { "Gimp",           NULL,       NULL,       1 << 6,       1,       -1 },
+	{ "Firefox",        NULL,       NULL,       1 << 1,       0,       -1 },
+	{ "Pidgin",         NULL,       NULL,       1 << 2,       1,        1 },
+	{ "Vlc",            NULL,       NULL,       1 << 5,       0,       -1 },
+	{ "Emacs",          NULL,       NULL,       1 << 3,       0,       -1 },
+	{ "Evince",         NULL,       NULL,       1 << 4,       0,       -1 },
+	{ "Gimp",           NULL,       NULL,       1 << 6,       1,       -1 },
 };
 
 /* layout(s) */
@@ -46,6 +41,7 @@ static const float mfact     = 0.55; /* factor of master area size [0.05..0.95]
 static const int nmaster     = 1;    /* number of clients in master area */
 static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
 static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */
+static const int refreshrate = 120;  /* refresh rate (per second) for client move/resize */
 
 static const Layout layouts[] = {
 	/* symbol     arrange function */
@@ -70,7 +66,7 @@ static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn()
 static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont, "-nb", col_gray1, "-nf", col_gray3, "-sb", col_cyan, "-sf", col_gray4, NULL };
 static const char *termcmd[]  = { "x-terminal-emulator", NULL };
 
-static Key keys[] = {
+static const Key keys[] = {
 	/* modifier                     key        function        argument */
 	{ MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
 	{ MODKEY|ShiftMask,             XK_Return, spawn,          {.v = termcmd } },
@@ -109,7 +105,7 @@ static Key keys[] = {
 
 /* button definitions */
 /* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
-static Button buttons[] = {
+static const Button buttons[] = {
 	/* click                event mask      button          function        argument */
 	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
 	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
